@@ -1,9 +1,10 @@
+import time
+
 from selenium import webdriver
 import allure
 from .utils.handle_loguru import log
 from time import strftime
 
-
 class Exec:
     def __init__(self,data):
         self.data = data
@@ -23,7 +24,7 @@ class Exec:
                 with allure.step(f'步骤{step}:{step_text}'):
                     self.driver.get(goto_data)
                     log.info(f'步骤{step}:{step_text}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screen/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name,'rb') as f:
                         file = f.read()
@@ -39,11 +40,12 @@ class Exec:
                 with allure.step(f'步骤{step}:{step_text}'):
                     ele =self.driver.find_element(*input_ele[:-1])
                     ele.clear()
+                    time.sleep(1)
                     ele.send_keys(input_ele[-1])
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={input_ele[:-1][0]},定位的值{input_ele[:-1][-1]}')
                     log.info(f'输入的值{input_ele[-1]}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screen/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -61,7 +63,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={click_data[0]},定位的值{click_data[-1]}')
                     log.info('点击元素')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screen/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
